/*
 * Copyright (C) 1996 Piero Orsoni
 */


#include <stdio.h>
#include <stdlib.h>
#include "pt.h"
#include "keywords.h"


char *Strip_Leading_Spaces (char *s) {
    long i;
    for (i = 0; (s[i] == ' ') || (s[i] == 9); i++);
    return &s[i];
}


char *Get_Value (char *s) {
    short i;
    for (i = 0; (s[i] != '=') && (i < strlen (s)); i++);
    if (s[i] != '=') return "\0";
    s = Strip_Leading_Spaces (&s[i+1]);
    if (strlen (s) < 1) return "\0";
    if ((s[strlen (s) - 1] == '\n') || (s[strlen (s) - 1] == '\r'))
	s[strlen (s) - 1] = '\0';
    if ((s[strlen (s) - 1] == '\n') || (s[strlen (s) - 1] == '\r'))
	s[strlen (s) - 1] = '\0';
    return s;
}


void Process_Options (char *s) {
    short i;
    for (i = 0; i < strlen (s); i++)
	if (s[i] == '-')
	    s[i] = ' ';
    Compute_Options (s);
}


void Compute_Line (char *line) {
    char *temp;
    line = Strip_Leading_Spaces (line);
    if ((line[0] >= 'A') && (line[0] <= 'z')) {
	if (!strncmp (line, c_options, strlen (c_options)))
	    Process_Options (Get_Value (line));
	else if (!strncmp (line, c_tab_size, strlen (c_tab_size)))
	    tab_size = atoi (Get_Value (line));
	else if (!strncmp (line, c_right_indent, strlen (c_right_indent))) {
	    temp = malloc (strlen (line) + 1);
	    strcpy (temp, Get_Value (line));
	    right_indent[right_indent_num] = malloc (strlen (temp) + 1);
	    strcpy (right_indent[right_indent_num++], temp);
	    free (temp);
	}
	else if (!strncmp (line, c_left_indent, strlen (c_left_indent))) {
	    temp = malloc (strlen (line) + 1);
	    strcpy (temp, Get_Value (line));
	    left_indent[left_indent_num] = malloc (strlen (temp) + 1);
	    strcpy (left_indent[left_indent_num++], temp);
	    free (temp);
	}
	else if (!strncmp (line, c_indent_size, strlen (c_indent_size)))
	    indent_size = atoi (Get_Value (line));
	else if (!strncmp (line, c_password, strlen (c_password))) {
	    temp = malloc (strlen (line) + 1);
	    strcpy (temp, Get_Value (line));
	    password = malloc (strlen (temp) + 1);
	    strcpy (password, temp);
	    free (temp);
	}
	else {
	    fprintf (stderr, "pt: wrong line in ptrc: %s\n",line);
	    exit (1);
	}
    }
    else if ((line[0] != 0) && (line[0] != '\n') && (line[0] != '\r')
	     && (line[0] != '#')) {
	fprintf (stderr, "pt: wrong line in .ptrc: %s\n",line);
	exit (1);
    }
    if (tab_size == 0) {
	fprintf (stderr, "pt: invalid tab_size in .ptrc, using default size of 8\n");
	tab_size = 8;
    }
    if (indent_size == 0) {
	fprintf (stderr, "pt: invalid indent_size in .ptrc, using default size of 4\n");
	indent_size = 4;
    }
}


void Load_Ptrc() {
    FILE *f;
    char line[256];
    char s[512];
    strcpy (s, HOME);
    strcat (s, RCNAME);
    if ((f = fopen (s, "r")) == NULL) {
	fprintf (stderr, "pt: cannot open %s, using defaults\n", s);
	return;
    }
    while (!feof (f)) {
	fgets (line, 255, f);
	Compute_Line (line);
    }
    fclose (f);
}


void Free_Indent() {
    char i;
    for (i = 0; i < left_indent_num; i++, free (left_indent[i]));
    for (i = 0; i < right_indent_num; i++, free (right_indent[i]));
}
